@@ -2,7 +2,8 @@
 
 Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
     1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-    2006, 2007, 2008, 2009, 2010 Massachusetts Institute of Technology
+    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
+    2017, 2018, 2019 Massachusetts Institute of Technology
 
 This file is part of MIT/GNU Scheme.
 
@@ -238,7 +239,7 @@ means scroll one screenful down."
 	(message (if (group-end? point)
 		     ""
 		     (let ((char (mark-right-char point)))
-		       (let ((n (char->ascii char)))
+		       (let ((n (char->integer char)))
 			 (string-append "Char: " (key-name char)
 					" ("
 					(if (zero? n) "" "0")
